# Next steps

-----

At this point you should have a basic understanding of how to use Hatch.

Now you may want to check out advanced configuration for [environments](config/environment.md) or [builds](config/build.md), set up your [preferred shell](config/hatch.md#shell), or read more about Hatch's [CLI](cli/about.md).

After that, check out the [Hatch Showcase](https://github.com/ofek/hatch-showcase) project to see examples of what is possible.

Finally, if you see a need, feel free to write a [plugin](plugins/about.md) for extended functionality.
